import pytest


@pytest.mark.parametrize('name', [
    ('waagent'),
])
def test_sles_azure_running_services(check_service, name):
    assert check_service(name)


@pytest.mark.parametrize('name', [
    ('cloud-init-local'),
    ('cloud-init'),
    ('cloud-config'),
    ('cloud-final')
])
def test_sles_azure_one_shot_services(check_service, host, name):
    assert check_service(name, running=None)

    if host.exists('systemctl'):
        # No clear way to check a service exited successfully using sysvinit
        output = host.run(
            "systemctl show -p Result {0} | sed 's/Result=//g'".format(name)
        )
        assert output.stdout.strip() == 'success'



# -*- coding: utf-8 -*-

"""openSUSE Leap distro module and sync points."""

# Copyright (c) 2019 SUSE LLC. All rights reserved.
#
# This file is part of img_proof. img_proof provides an api and command line
# utilities for testing images in the Public Cloud.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from img_proof.ipa_sles import SLES


class openSUSE_Leap(SLES):
    """openSUSE Leap distro class."""



#!/usr/bin/python3
# -*- coding: utf-8 -*-

"""img_proof RHEL distro unit tests."""

# Copyright (c) 2020 Neal Gompa. All rights reserved.
#
# This file is part of img_proof. img_proof provides an api and command line
# utilities for testing images in the Public Cloud.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from img_proof.ipa_rhel import RHEL

from unittest.mock import MagicMock, patch


def test_rhel_set_init_system():
    """Test RHEL set init system method."""
    client = MagicMock()
    rhel = RHEL()

    with patch('img_proof.ipa_utils.execute_ssh_command',
               MagicMock(return_value='systemd')) as mocked:
        rhel._set_init_system(client)

    assert rhel.init_system == 'systemd'
    mocked.assert_called_once_with(client, 'ps -p 1 -o comm=')



import pytest


def test_sles_ec2_billing_code(
    get_ec2_billing_products,
    is_byos,
    get_release_value
):
    try:
        products = get_ec2_billing_products()
    except Exception:
        # CHOST images have no ec2metdata.
        pytest.skip(
            'ec2metadata not in image, cannot determine billing products.'
        )

    variant = get_release_value('VARIANT_ID')
    byos = is_byos()

    if byos or (variant == 'sles-sap' and not byos):
        assert products is None
    else:
        assert products



#!/usr/bin/python3
# -*- coding: utf-8 -*-

"""img_proof distro unit tests."""

# Copyright (c) 2019 SUSE LLC. All rights reserved.
#
# This file is part of img_proof. img_proof provides an api and command line
# utilities for testing images in the Public Cloud.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from img_proof.ipa_distro import Distro
from img_proof.ipa_exceptions import IpaDistroException

from unittest.mock import call, MagicMock, patch

import pytest

methods = [
    'get_install_cmd',
    'get_refresh_repo_cmd',
    'get_stop_ssh_service_cmd',
    'get_update_cmd'
]


@pytest.mark.parametrize(
    "method",
    methods,
    ids=methods
)
def test_distro_not_implemented_methods(method):
    """Confirm methods raise not implemented exception."""
    distro = Distro()
    pytest.raises(
        NotImplementedError,
        getattr(distro, method)
    )


def test_distro_set_init_system_exception():
    """Test distro set init system method exception."""
    client = MagicMock()
    distro = Distro()

    with patch('img_proof.ipa_utils.execute_ssh_command', MagicMock(
               side_effect=Exception('ERROR!'))) as mocked:
        pytest.raises(
            IpaDistroException,
            distro._set_init_system,
            client
        )

    mocked.assert_called_once_with(client, 'ps -p 1 -o comm=')


def test_distro_get_commands():
    """Test distro reboot and sudo command return values."""
    distro = Distro()
    assert distro.get_reboot_cmd() == 'shutdown -r now'
    assert distro.get_sudo_exec_wrapper() == 'sudo sh -c'


def test_distro_get_vm_info():
    """Test distro get vm info method."""
    client = MagicMock()
    distro = Distro()
    distro.init_system = 'systemd'

    with patch('img_proof.ipa_utils.execute_ssh_command',
               MagicMock(return_value='')) as mocked:
        distro.get_vm_info(client)

    mocked.assert_has_calls([
        call(client, 'systemd-analyze'),
        call(client, 'systemd-analyze blame'),
        call(client, 'sudo journalctl -b')
    ])



#!/usr/bin/python3
# -*- coding: utf-8 -*-

"""Setup script."""

# Copyright (c) 2019 SUSE LLC
#
# This file is part of img-proof. img-proof provides an api and command line
# utilities for testing images in the Public Cloud.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from setuptools import find_packages, setup

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('requirements.txt') as req_file:
    requirements = req_file.read().splitlines()

with open('requirements-test.txt') as req_file:
    test_requirements = req_file.read().splitlines()[2:]

with open('requirements-dev.txt') as req_file:
    dev_requirements = test_requirements + req_file.read().splitlines()[2:]

tox_requirements = [
    'tox',
    'tox-pyenv'
]


setup(
    name='img-proof',
    version='7.13.0',
    description="Package for automated testing of cloud images.",
    long_description=readme,
    long_description_content_type="text/markdown",
    author="SUSE",
    author_email='public-cloud-dev@susecloud.net',
    url='https://github.com/SUSE-Enceladus/img-proof',
    packages=find_packages(),
    package_dir={
        'img_proof': 'img_proof'
    },
    entry_points={
        'console_scripts': [
            'img-proof=img_proof.scripts.cli:main'
        ]
    },
    include_package_data=True,
    python_requires='>=3.4',
    install_requires=requirements,
    extras_require={
        'dev': dev_requirements,
        'test': test_requirements,
        'tox': tox_requirements
    },
    license='GPLv3+',
    zip_safe=False,
    keywords='img-proof img_proof',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Testing',
        'License :: OSI Approved :: '
        'GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
)



def test_sles_motd(host, get_release_value):
    motd = host.file('/etc/motd')
    assert motd.exists
    assert motd.is_file

    pretty_name = get_release_value('PRETTY_NAME')
    assert pretty_name

    version = get_release_value('VERSION')
    assert version

    assert (
        motd.contains(pretty_name) or
        motd.contains(
            'SUSE Linux Enterprise Server {0}'.format(
                version.replace('-', ' ')
            )
        )
    )
